diff artifacts/src/main/java/org/dive4elements/river/artifacts/access/GaugeAccess.java @ 5865:73da40528cf2

River artifacts: Renamed FLYSUtils to RiverUtils.
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 28 Apr 2013 15:09:31 +0200
parents 4897a58c8746
children 59ff03ff48f1
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/artifacts/access/GaugeAccess.java	Sun Apr 28 15:04:44 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/artifacts/access/GaugeAccess.java	Sun Apr 28 15:09:31 2013 +0200
@@ -12,10 +12,10 @@
 
 import org.dive4elements.artifacts.CallContext;
 import org.dive4elements.river.artifacts.FLYSArtifact;
-import org.dive4elements.river.utils.FLYSUtils;
+import org.dive4elements.river.utils.RiverUtils;
 
 /** For the moment, light-weight wrapper around FLYSUtils. */
 // TODO employ 'Caching' like other Accesses, remove usage of FLYSUtils.
 public class GaugeAccess
 extends RangeAccess
 {
@@ -27,9 +27,9 @@
 
 
     public String getGaugeName() {
-        return FLYSUtils.getGaugename(this.getArtifact());
+        return RiverUtils.getGaugename(this.getArtifact());
     }
 
     // TODO there is also getGauges in FLYSUtils...
 }
 // vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
@@ -12,10 +12,10 @@
 
-/** For the moment, light-weight wrapper around FLYSUtils. */
-// TODO employ 'Caching' like other Accesses, remove usage of FLYSUtils.
+/** For the moment, light-weight wrapper around RiverUtils. */
+// TODO employ 'Caching' like other Accesses, remove usage of RiverUtils.
 public class GaugeAccess
 extends RangeAccess
@@ -27,9 +27,9 @@
     }
 
-    // TODO there is also getGauges in FLYSUtils...
+    // TODO there is also getGauges in RiverUtils...
 }
 // vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :

http://dive4elements.wald.intevation.org